Owl
=====

Owl is a python Consul config center for Tornado, Gevent, Flask and AioHTTP. It supports:

* reading from remote config systems (Consul), and watching changes
* auto config value type convert
* json string value auto decode to config option

It is originally created by XTQXK <xtqxk.kilroy@gmail.com>.

Installation
------------

``pip install consul-owl``

License
------------

Owl is under Apache 2.0 license. See the LICENSE file for details.
